@@ -33,9 +33,9 @@ import (
 )
 
 func TestDuplicateParameters(t *testing.T) {
-	RegisterTestingT(t)
+	g := NewWithT(t)
 
-	ctx, cancel := context.WithCancel(TestContext)
+	ctx, cancel := context.WithCancel(TestContext())
 	defer cancel()
 
 	// run kamel to output the traits/configuration structure in json format to check the processed values
@@ -52,5 +52,5 @@ func TestDuplicateParameters(t *testing.T) {
 
 	outParams :=
 		`"traits":{"affinity":{"enabled":true},"camel":{"properties":["prop1 = true","prop2 = true","foo = bar"]},"pull-secret":{"enabled":true},"addons":{"telemetry":{"enabled":true}}}`
-	Expect(commOutput).To(ContainSubstring(outParams))
+	g.Expect(commOutput).To(ContainSubstring(outParams))
 }
