@@ -27,34 +27,31 @@ import (
 
 	. "github.com/apache/camel-k/v2/e2e/support"
 	. "github.com/onsi/gomega"
-	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	"io/ioutil"
 )
 
 func TestOpenAPIService(t *testing.T) {
-	RegisterTestingT(t)
+	ctx := TestContext()
+	g := NewWithT(t)
 
 	openapiContent, err := ioutil.ReadFile("./files/petstore-api.yaml")
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	var cmDataProps = make(map[string]string)
 	cmDataProps["petstore-api.yaml"] = string(openapiContent)
-	CreatePlainTextConfigmap(ns, "my-openapi-knative", cmDataProps)
+	CreatePlainTextConfigmap(t, ctx, ns, "my-openapi-knative", cmDataProps)
 
-	Expect(KamelRunWithID(operatorID, ns,
-		"--name", "petstore",
-		"--open-api", "configmap:my-openapi-knative",
-		"files/petstore.groovy",
-	).Execute()).To(Succeed())
+	g.Expect(KamelRunWithID(t, ctx, operatorID, ns, "--name", "petstore", "--open-api", "configmap:my-openapi-knative", "files/petstore.groovy").Execute()).To(Succeed())
 
-	Eventually(KnativeService(ns, "petstore"), TestTimeoutLong).
+	g.Eventually(KnativeService(t, ctx, ns, "petstore"), TestTimeoutLong).
 		Should(Not(BeNil()))
 
-	Eventually(IntegrationLogs(ns, "petstore"), TestTimeoutMedium).
+	g.Eventually(IntegrationLogs(t, ctx, ns, "petstore"), TestTimeoutMedium).
 		Should(ContainSubstring("Started listPets (rest://get:/v1:/pets)"))
-	Eventually(IntegrationLogs(ns, "petstore"), TestTimeoutMedium).
+	g.Eventually(IntegrationLogs(t, ctx, ns, "petstore"), TestTimeoutMedium).
 		Should(ContainSubstring("Started createPets (rest://post:/v1:/pets)"))
-	Eventually(IntegrationLogs(ns, "petstore"), TestTimeoutMedium).
+	g.Eventually(IntegrationLogs(t, ctx, ns, "petstore"), TestTimeoutMedium).
 		Should(ContainSubstring("Started showPetById (rest://get:/v1:/pets/%7BpetId%7D)"))
 
-	Expect(Kamel("delete", "--all", "-n", ns).Execute()).To(Succeed())
+	g.Expect(Kamel(t, ctx, "delete", "--all", "-n", ns).Execute()).To(Succeed())
 }
