@@ -17,9 +17,7 @@ limitations under the License.
 
 package apis
 
-import (
-	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
-)
+import v1alpha1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1alpha1"
 
 func init() {
 	// Register the types with the Scheme so the components can map objects to GroupVersionKinds and back
