@@ -22,7 +22,7 @@ package trait
 //
 // +camel-k:trait=deployer.
 type DeployerTrait struct {
-	Trait `property:",squash" json:",inline"`
+	PlatformBaseTrait `property:",squash" json:",inline"`
 	// Allows to explicitly select the desired deployment kind between `deployment`, `cron-job` or `knative-service` when creating the resources for running the integration.
 	// +kubebuilder:validation:Enum=deployment;cron-job;knative-service
 	Kind string `property:"kind" json:"kind,omitempty"`
