@@ -66,13 +66,13 @@ func newReconciler(mgr manager.Manager, c client.Client) reconcile.Reconciler {
 }
 
 func add(mgr manager.Manager, r reconcile.Reconciler) error {
-	c, err := controller.New("kamelet-binding-controller", mgr, controller.Options{Reconciler: r})
+	c, err := controller.New("pipe-controller", mgr, controller.Options{Reconciler: r})
 	if err != nil {
 		return err
 	}
 
 	// Watch for changes to primary resource Pipe
-	err = c.Watch(&source.Kind{Type: &v1.Pipe{}},
+	err = c.Watch(source.Kind(mgr.GetCache(), &v1.Pipe{}),
 		&handler.EnqueueRequestForObject{},
 		platform.FilteringFuncs{
 			UpdateFunc: func(e event.UpdateEvent) bool {
@@ -114,10 +114,14 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	}
 
 	// Watch Integration to propagate changes downstream
-	err = c.Watch(&source.Kind{Type: &v1.Integration{}}, &handler.EnqueueRequestForOwner{
-		OwnerType:    &v1.Pipe{},
-		IsController: false,
-	})
+	err = c.Watch(source.Kind(mgr.GetCache(), &v1.Integration{}),
+		handler.EnqueueRequestForOwner(
+			mgr.GetScheme(),
+			mgr.GetRESTMapper(),
+			&v1.Pipe{},
+			handler.OnlyControllerOwner(),
+		),
+	)
 	if err != nil {
 		return err
 	}
