@@ -63,6 +63,10 @@ func (t *camelTrait) Matches(trait Trait) bool {
 }
 
 func (t *camelTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration != nil && e.Integration.IsSynthetic() {
+		return false, NewIntegrationConditionPlatformDisabledWithMessage("Camel", "synthetic integration"), nil
+	}
+
 	if t.RuntimeVersion == "" {
 		if runtimeVersion, err := determineRuntimeVersion(e); err != nil {
 			return false, nil, err
@@ -71,23 +75,25 @@ func (t *camelTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
 		}
 	}
 
-	// Don't run this trait for a synthetic Integration
-	return e.Integration == nil || !e.Integration.IsSynthetic(), nil, nil
+	return true, nil, nil
 }
 
 func (t *camelTrait) Apply(e *Environment) error {
-	if t.RuntimeVersion == "" {
-		return errors.New("unable to determine runtime version")
+	if e.IntegrationKit != nil && e.IntegrationKit.IsSynthetic() {
+		// This is required as during init phase, the trait set by default these values
+		// which are widely used in the platform for different purposese.
+		if e.Integration != nil {
+			e.Integration.Status.RuntimeVersion = ""
+			e.Integration.Status.RuntimeProvider = ""
+		}
+		return nil
 	}
-
 	if e.CamelCatalog == nil {
 		if err := t.loadOrCreateCatalog(e, t.RuntimeVersion); err != nil {
 			return err
 		}
 	}
-
-	e.RuntimeVersion = t.RuntimeVersion
-
+	e.RuntimeVersion = e.CamelCatalog.Runtime.Version
 	if e.Integration != nil {
 		e.Integration.Status.RuntimeVersion = e.CamelCatalog.Runtime.Version
 		e.Integration.Status.RuntimeProvider = e.CamelCatalog.Runtime.Provider
@@ -96,13 +102,11 @@ func (t *camelTrait) Apply(e *Environment) error {
 		e.IntegrationKit.Status.RuntimeVersion = e.CamelCatalog.Runtime.Version
 		e.IntegrationKit.Status.RuntimeProvider = e.CamelCatalog.Runtime.Provider
 	}
-
 	if e.IntegrationKitInPhase(v1.IntegrationKitPhaseReady) && e.IntegrationInRunningPhases() {
 		// Get all resources
 		maps := t.computeConfigMaps(e)
 		e.Resources.AddAll(maps)
 	}
-
 	return nil
 }
 
