@@ -30,7 +30,7 @@ import (
 )
 
 type environmentTrait struct {
-	BaseTrait
+	BasePlatformTrait
 	traitv1.EnvironmentTrait `property:",squash"`
 }
 
@@ -54,19 +54,19 @@ const (
 
 func newEnvironmentTrait() Trait {
 	return &environmentTrait{
-		BaseTrait: NewBaseTrait("environment", 800),
+		BasePlatformTrait: NewBasePlatformTrait("environment", 800),
 		EnvironmentTrait: traitv1.EnvironmentTrait{
 			ContainerMeta: pointer.Bool(true),
 		},
 	}
 }
 
-func (t *environmentTrait) Configure(e *Environment) (bool, error) {
-	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
-		return false, nil
+func (t *environmentTrait) Configure(e *Environment) (bool, *TraitCondition, error) {
+	if e.Integration == nil {
+		return false, nil, nil
 	}
 
-	return e.IntegrationInRunningPhases(), nil
+	return e.IntegrationInRunningPhases(), nil, nil
 }
 
 func (t *environmentTrait) Apply(e *Environment) error {
@@ -105,8 +105,3 @@ func (t *environmentTrait) Apply(e *Environment) error {
 
 	return nil
 }
-
-// IsPlatformTrait overrides base class method.
-func (t *environmentTrait) IsPlatformTrait() bool {
-	return true
-}
