@@ -21,6 +21,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -34,10 +35,11 @@ func TestConfigureJolokiaTraitInRunningPhaseDoesSucceed(t *testing.T) {
 	trait, environment := createNominalJolokiaTest()
 	environment.Integration.Status.Phase = v1.IntegrationPhaseRunning
 
-	configured, err := trait.Configure(environment)
+	configured, condition, err := trait.Configure(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.True(t, configured)
+	assert.Nil(t, condition)
 }
 
 func TestApplyJolokiaTraitNominalShouldSucceed(t *testing.T) {
@@ -45,13 +47,13 @@ func TestApplyJolokiaTraitNominalShouldSucceed(t *testing.T) {
 
 	err := trait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	container := environment.Resources.GetContainerByName(defaultContainerName)
 	assert.NotNil(t, container)
 
 	assert.Equal(t, container.Args, []string{
-		"-javaagent:dependencies/lib/main/org.jolokia.jolokia-jvm-1.7.1.jar=discoveryEnabled=false,host=*,port=8778",
+		"-javaagent:dependencies/lib/main/org.jolokia.jolokia-agent-jvm-1.7.1.jar=discoveryEnabled=false,host=*,port=8778",
 	})
 
 	assert.Len(t, container.Ports, 1)
@@ -72,13 +74,13 @@ func TestApplyJolokiaTraitForOpenShiftProfileShouldSucceed(t *testing.T) {
 
 	err := trait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	container := environment.Resources.GetContainerByName(defaultContainerName)
 	assert.NotNil(t, container)
 
 	assert.Equal(t, container.Args, []string{
-		"-javaagent:dependencies/lib/main/org.jolokia.jolokia-jvm-1.7.1.jar=caCert=/var/run/secrets/kubernetes.io/serviceaccount/service-ca.crt," +
+		"-javaagent:dependencies/lib/main/org.jolokia.jolokia-agent-jvm-1.7.1.jar=caCert=/var/run/secrets/kubernetes.io/serviceaccount/service-ca.crt," +
 			"clientPrincipal.1=cn=system:master-proxy,clientPrincipal.2=cn=hawtio-online.hawtio.svc," +
 			"clientPrincipal.3=cn=fuse-console.fuse.svc,discoveryEnabled=false,extendedClientCheck=true," +
 			"host=*,port=8778,protocol=https,useSslClientAuthentication=true",
@@ -102,7 +104,7 @@ func TestApplyJolokiaTraitWithoutContainerShouldReportJolokiaUnavailable(t *test
 
 	err := trait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 	assert.Len(t, environment.Integration.Status.Conditions, 1)
 	condition := environment.Integration.Status.Conditions[0]
 	assert.Equal(t, v1.IntegrationConditionJolokiaAvailable, condition.Type)
@@ -123,12 +125,12 @@ func TestApplyJolokiaTraitWithOptionShouldOverrideDefault(t *testing.T) {
 
 	err := trait.Apply(environment)
 
-	assert.Nil(t, err)
+	require.NoError(t, err)
 
 	container := environment.Resources.GetContainerByName(defaultContainerName)
 
 	assert.Equal(t, container.Args, []string{
-		"-javaagent:dependencies/lib/main/org.jolokia.jolokia-jvm-1.7.1.jar=caCert=.cacert,clientPrincipal=cn:any," +
+		"-javaagent:dependencies/lib/main/org.jolokia.jolokia-agent-jvm-1.7.1.jar=caCert=.cacert,clientPrincipal=cn:any," +
 			"discoveryEnabled=true,extendedClientCheck=false,host=explicit-host,port=8778,protocol=http," +
 			"useSslClientAuthentication=false",
 	})
@@ -140,7 +142,7 @@ func TestApplyJolokiaTraitWithUnparseableOptionShouldReturnError(t *testing.T) {
 
 	err := trait.Apply(environment)
 
-	assert.NotNil(t, err)
+	require.Error(t, err)
 }
 
 func TestSetDefaultJolokiaOptionShouldNotOverrideOptionsMap(t *testing.T) {
@@ -202,7 +204,7 @@ func TestSetDefaultBoolJolokiaOptionShouldSucceed(t *testing.T) {
 
 	trait.setDefaultJolokiaOption(options, &option, "key", true)
 
-	assert.Equal(t, true, *option)
+	assert.True(t, *option)
 }
 
 func TestSetDefaultBoolJolokiaOptionShouldNotOverrideExistingValue(t *testing.T) {
@@ -212,7 +214,7 @@ func TestSetDefaultBoolJolokiaOptionShouldNotOverrideExistingValue(t *testing.T)
 
 	trait.setDefaultJolokiaOption(options, &option, "key", true)
 
-	assert.Equal(t, false, *option)
+	assert.False(t, *option)
 }
 
 func TestAddStringOptionToJolokiaOptions(t *testing.T) {
@@ -284,8 +286,8 @@ func createNominalJolokiaTest() (*jolokiaTrait, *Environment) {
 			Status: v1.IntegrationKitStatus{
 				Artifacts: []v1.Artifact{
 					{
-						ID:     "org.jolokia.jolokia-jvm-1.7.1.jar",
-						Target: "dependencies/lib/main/org.jolokia.jolokia-jvm-1.7.1.jar",
+						ID:     "org.jolokia.jolokia-agent-jvm-1.7.1.jar",
+						Target: "dependencies/lib/main/org.jolokia.jolokia-agent-jvm-1.7.1.jar",
 					},
 				},
 			},
