@@ -40,9 +40,10 @@ func TestConfigurationNoKameletsUsed(t *testing.T) {
     steps:
     - to: log:info
 `)
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.False(t, enabled)
+	assert.Nil(t, condition)
 	assert.Equal(t, "", trait.List)
 }
 
@@ -60,9 +61,10 @@ func TestConfigurationWithKamelets(t *testing.T) {
     - to: kamelet://complex-.-.-1b/a
     - to: kamelet://complex-.-.-1c/b
 `)
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 	assert.Equal(t, []string{"c0", "c1", "c2", "complex-.-.-1a", "complex-.-.-1b", "complex-.-.-1c"}, trait.getKameletKeys())
 	assert.Equal(t, []configurationKey{
 		newConfigurationKey("c0", ""),
@@ -98,18 +100,18 @@ func TestKameletLookup(t *testing.T) {
 				"camel:log",
 			},
 		},
-		Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 	})
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
 	cm := environment.Resources.GetConfigMap(func(_ *corev1.ConfigMap) bool { return true })
 	assert.NotNil(t, cm)
-	assert.Equal(t, "it-kamelet-timer-template", cm.Name)
+	assert.Equal(t, "kamelets-bundle-it-001", cm.Name)
 	assert.Equal(t, "test", cm.Namespace)
 
 	assert.Len(t, environment.Integration.Status.GeneratedSources, 1)
@@ -147,11 +149,11 @@ func TestKameletSecondarySourcesLookup(t *testing.T) {
 				},
 			},
 		},
-		Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 	})
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 
 	err = trait.Apply(environment)
@@ -198,18 +200,18 @@ func TestNonYAMLKameletLookup(t *testing.T) {
 				},
 			},
 		},
-		Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 	})
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
 	cm := environment.Resources.GetConfigMap(func(_ *corev1.ConfigMap) bool { return true })
 	assert.NotNil(t, cm)
-	assert.Equal(t, "it-kamelet-timer-000", cm.Name)
+	assert.Equal(t, "kamelets-bundle-it-001", cm.Name)
 	assert.Equal(t, "test", cm.Namespace)
 
 	assert.Len(t, environment.Integration.Status.GeneratedSources, 1)
@@ -250,7 +252,6 @@ func TestMultipleKamelets(t *testing.T) {
 				"camel:xxx",
 			},
 		},
-		Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 	}, &v1.Kamelet{
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace: "test",
@@ -274,11 +275,11 @@ func TestMultipleKamelets(t *testing.T) {
 				"camel:tbd",
 			},
 		},
-		Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 	})
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 	assert.Equal(t, []string{"logger", "timer"}, trait.getKameletKeys())
 
 	err = trait.Apply(environment)
@@ -336,7 +337,6 @@ func TestKameletConfigLookup(t *testing.T) {
 				"camel:log",
 			},
 		},
-		Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 	}, &corev1.Secret{
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace: "test",
@@ -363,18 +363,17 @@ func TestKameletConfigLookup(t *testing.T) {
 			},
 		},
 	})
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 	assert.Equal(t, []configurationKey{newConfigurationKey("timer", "")}, trait.getConfigurationKeys())
 
-	err = trait.Apply(environment)
+	list, err := trait.listConfigurationSecrets(environment)
 	require.NoError(t, err)
-	assert.Len(t, environment.Integration.Status.Configuration, 2)
-	assert.Contains(t, environment.Integration.Status.Configuration, v1.ConfigurationSpec{Type: "secret", Value: "my-secret"})
-	assert.NotContains(t, environment.Integration.Status.Configuration, v1.ConfigurationSpec{Type: "secret", Value: "my-secret2"})
-	assert.Contains(t, environment.Integration.Status.Configuration, v1.ConfigurationSpec{Type: "secret", Value: "my-secret3"})
+	assert.Contains(t, list, "my-secret", "my-secret3")
+	assert.NotContains(t, list, "my-secret2")
 }
 
 func TestKameletNamedConfigLookup(t *testing.T) {
@@ -399,7 +398,6 @@ func TestKameletNamedConfigLookup(t *testing.T) {
 				"camel:log",
 			},
 		},
-		Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 	}, &corev1.Secret{
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace: "test",
@@ -427,21 +425,20 @@ func TestKameletNamedConfigLookup(t *testing.T) {
 			},
 		},
 	})
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 	assert.Equal(t, []string{"timer"}, trait.getKameletKeys())
 	assert.Equal(t, []configurationKey{
 		newConfigurationKey("timer", ""),
 		newConfigurationKey("timer", "id2"),
 	}, trait.getConfigurationKeys())
 
-	err = trait.Apply(environment)
+	list, err := trait.listConfigurationSecrets(environment)
 	require.NoError(t, err)
-	assert.Len(t, environment.Integration.Status.Configuration, 2)
-	assert.Contains(t, environment.Integration.Status.Configuration, v1.ConfigurationSpec{Type: "secret", Value: "my-secret"})
-	assert.Contains(t, environment.Integration.Status.Configuration, v1.ConfigurationSpec{Type: "secret", Value: "my-secret2"})
-	assert.NotContains(t, environment.Integration.Status.Configuration, v1.ConfigurationSpec{Type: "secret", Value: "my-secret3"})
+	assert.Contains(t, list, "my-secret", "my-secret2")
+	assert.NotContains(t, list, "my-secret3")
 }
 
 func TestKameletConditionFalse(t *testing.T) {
@@ -465,22 +462,22 @@ func TestKameletConditionFalse(t *testing.T) {
 					},
 				}),
 			},
-			Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 		})
 
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 
 	err = trait.Apply(environment)
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.Len(t, environment.Integration.Status.Conditions, 1)
 
 	cond := environment.Integration.Status.GetCondition(v1.IntegrationConditionKameletsAvailable)
 	assert.Equal(t, corev1.ConditionFalse, cond.Status)
 	assert.Equal(t, v1.IntegrationConditionKameletsAvailableReason, cond.Reason)
 	assert.Contains(t, cond.Message, "[timer] found")
-	assert.Contains(t, cond.Message, "[none] not found")
+	assert.Contains(t, cond.Message, "kamelets [none] not found")
 }
 
 func TestKameletConditionTrue(t *testing.T) {
@@ -504,7 +501,6 @@ func TestKameletConditionTrue(t *testing.T) {
 					},
 				}),
 			},
-			Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 		},
 		&v1.Kamelet{
 			ObjectMeta: metav1.ObjectMeta{
@@ -518,12 +514,12 @@ func TestKameletConditionTrue(t *testing.T) {
 					},
 				}),
 			},
-			Status: v1.KameletStatus{Phase: v1.KameletPhaseReady},
 		})
 
-	enabled, err := trait.Configure(environment)
+	enabled, condition, err := trait.Configure(environment)
 	require.NoError(t, err)
 	assert.True(t, enabled)
+	assert.Nil(t, condition)
 
 	err = trait.Apply(environment)
 	require.NoError(t, err)
